.. _spkg_sphinxcontrib_jsmath:

sphinxcontrib_jsmath: Sphinx extension which renders display math in HTML via JavaScript
========================================================================================

Description
-----------

Sphinx extension which renders display math in HTML via JavaScript

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/sphinxcontrib-jsmath/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.0.1

version_requirements.txt::

    sphinxcontrib_jsmath >=1.0.1

See https://repology.org/project/python:sphinxcontrib-jsmath/versions

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install sphinxcontrib_jsmath\>=1.0.1

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i sphinxcontrib_jsmath

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-sphinxcontrib-jsmath

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install sphinxcontrib-jsmath

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install textproc/py-sphinxcontrib-jsmath

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/sphinxcontrib-jsmath

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py37-sphinxcontrib-jsmath

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3-sphinxcontrib-jsmath

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-sphinxcontrib-jsmath


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
